==> stoobly_agent-0.13.5-py3-none-any.whl: stoobly_agent/test/mock_data/endpoint_show_response.py <==
endpoint_show_response = {
  "response_param_names": [
    {
      "created_at": "2022-05-31T07:48:32.700Z",
      "id": 431,
      "inferred_type": "Integer",
      "is_deterministic": True,
      "is_required": True,
      "name": "requests_count",
      "query": "[*].requests_count",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.700Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.722Z",
      "id": 433,
      "inferred_type": "Integer",
      "is_deterministic": True,
      "is_required": True,
      "name": "category",
      "query": "[*].category",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.722Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.780Z",
      "id": 440,
      "inferred_type": "String",
      "is_deterministic": False,
      "is_required": True,
      "name": "created_at",
      "query": "[*].created_at",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-06-15T01:07:41.094Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.864Z",
      "id": 444,
      "inferred_type": "String",
      "is_deterministic": True,
      "is_required": True,
      "name": "url",
      "query": "[*].url",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.864Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.742Z",
      "id": 435,
      "inferred_type": "String",
      "is_deterministic": True,
      "is_required": True,
      "name": "path",
      "query": "[*].path",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.742Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.760Z",
      "id": 437,
      "inferred_type": "String",
      "is_deterministic": True,
      "is_required": True,
      "name": "method",
      "query": "[*].method",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.760Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.812Z",
      "id": 442,
      "inferred_type": "String",
      "is_deterministic": False,
      "is_required": True,
      "name": "updated_at",
      "query": "[*].updated_at",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-06-15T01:07:43.561Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.834Z",
      "id": 443,
      "inferred_type": "Array",
      "is_deterministic": True,
      "is_required": True,
      "name": "components",
      "query": "[*].components",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.834Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.679Z",
      "id": 428,
      "inferred_type": "Integer",
      "is_deterministic": False,
      "is_required": True,
      "name": "id",
      "query": "[*].id",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-06-15T01:08:06.946Z",
      "alias_name": ":endpointId",
      "alias_id": 106,
      "alias": {
        "id": 106,
        "name": ":endpointId",
        "created_at": "2022-05-31T07:03:40.975Z",
        "updated_at": "2022-05-31T07:03:40.975Z",
        "project_id": 37,
        "path_segment_names_count": 1,
        "header_names_count": 0,
        "query_param_names_count": 1,
        "body_param_names_count": 0,
        "response_param_names_count": 3
      }
    },
    {
      "created_at": "2022-05-31T07:48:32.635Z",
      "id": 426,
      "inferred_type": "Hash",
      "is_deterministic": True,
      "is_required": True,
      "name": "Element",
      "query": "[*]",
      "requests_count": 2,
      "response_param_name_id": None,
      "updated_at": "2022-06-06T08:21:50.835Z"
    }
  ]
}

==> stoobly_agent-0.13.7-py3-none-any.whl: stoobly_agent/test/mock_data/endpoint_show_response.py <==
endpoint_show_response = {
  "response_param_names": [
    {
      "created_at": "2022-05-31T07:48:32.700Z",
      "id": 431,
      "inferred_type": "Integer",
      "is_deterministic": True,
      "is_required": True,
      "name": "requests_count",
      "query": "[*].requests_count",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.700Z",
      "alias_id": 107,
      "alias_name": ":endpointRequestsCount", 
      "alias": {
        "id": 107,
        "name": ":endpointRequestsCount",
        "created_at": "2022-05-31T07:03:40.975Z",
        "updated_at": "2022-05-31T07:03:40.975Z",
        "project_id": 37,
        "path_segment_names_count": 1,
        "header_names_count": 0,
        "query_param_names_count": 1,
        "body_param_names_count": 0,
        "response_param_names_count": 3
      }
    },
    {
      "created_at": "2022-05-31T07:48:32.722Z",
      "id": 433,
      "inferred_type": "Integer",
      "is_deterministic": True,
      "is_required": True,
      "name": "category",
      "query": "[*].category",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.722Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.780Z",
      "id": 440,
      "inferred_type": "String",
      "is_deterministic": False,
      "is_required": True,
      "name": "created_at",
      "query": "[*].created_at",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-06-15T01:07:41.094Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.864Z",
      "id": 444,
      "inferred_type": "String",
      "is_deterministic": True,
      "is_required": True,
      "name": "url",
      "query": "[*].url",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.864Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.742Z",
      "id": 435,
      "inferred_type": "String",
      "is_deterministic": True,
      "is_required": True,
      "name": "path",
      "query": "[*].path",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.742Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.760Z",
      "id": 437,
      "inferred_type": "String",
      "is_deterministic": True,
      "is_required": True,
      "name": "method",
      "query": "[*].method",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.760Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.812Z",
      "id": 442,
      "inferred_type": "String",
      "is_deterministic": False,
      "is_required": True,
      "name": "updated_at",
      "query": "[*].updated_at",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-06-15T01:07:43.561Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.834Z",
      "id": 443,
      "inferred_type": "Array",
      "is_deterministic": True,
      "is_required": True,
      "name": "components",
      "query": "[*].components",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-05-31T07:48:32.834Z"
    },
    {
      "created_at": "2022-05-31T07:48:32.679Z",
      "id": 428,
      "inferred_type": "Integer",
      "is_deterministic": False,
      "is_required": True,
      "name": "id",
      "query": "[*].id",
      "requests_count": 2,
      "response_param_name_id": 426,
      "updated_at": "2022-06-15T01:08:06.946Z",
      "alias_name": ":endpointId",
      "alias_id": 106,
      "alias": {
        "id": 106,
        "name": ":endpointId",
        "created_at": "2022-05-31T07:03:40.975Z",
        "updated_at": "2022-05-31T07:03:40.975Z",
        "project_id": 37,
        "path_segment_names_count": 1,
        "header_names_count": 0,
        "query_param_names_count": 1,
        "body_param_names_count": 0,
        "response_param_names_count": 3
      }
    },
    {
      "created_at": "2022-05-31T07:48:32.635Z",
      "id": 426,
      "inferred_type": "Hash",
      "is_deterministic": True,
      "is_required": True,
      "name": "Element",
      "query": "[*]",
      "requests_count": 2,
      "response_param_name_id": None,
      "updated_at": "2022-06-06T08:21:50.835Z"
    }
  ]
}
